==> jboss-osgi-hotdeploy-1.0.1-sources.jar: org/jboss/osgi/hotdeploy/internal/DeploymentScannerActivator.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.hotdeploy.internal;

//$Id: DeploymentScannerActivator.java 91058 2009-07-10 10:04:11Z thomas.diesler@jboss.com $

import org.jboss.osgi.spi.service.DeploymentScannerService;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

/**
 * The {@link DeploymentScannerService} service activator
 * 
 * @author thomas.diesler@jboss.com
 * @since 27-May-2009
 */
public class DeploymentScannerActivator implements BundleActivator
{
   private DeploymentScannerImpl service;
   
   public void start(BundleContext context)
   {
      service = new DeploymentScannerImpl(context);
      context.registerService(DeploymentScannerService.class.getName(), service, null);
      
      service.start();
   }

   public void stop(BundleContext context)
   {
      if (service != null)
      {
         service.stop();
         service = null;
      }
   }
}

==> jboss-osgi-hotdeploy-1.0.3-sources.jar: org/jboss/osgi/hotdeploy/internal/DeploymentScannerActivator.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.hotdeploy.internal;

//$Id: DeploymentScannerActivator.java 95375 2009-10-22 06:01:08Z thomas.diesler@jboss.com $

import org.jboss.osgi.hotdeploy.DeploymentScannerService;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

/**
 * The {@link DeploymentScannerService} service activator
 * 
 * @author thomas.diesler@jboss.com
 * @since 27-May-2009
 */
public class DeploymentScannerActivator implements BundleActivator
{
   private DeploymentScannerImpl service;
   
   public void start(BundleContext context)
   {
      service = new DeploymentScannerImpl(context);
      context.registerService(DeploymentScannerService.class.getName(), service, null);
      
      service.start();
   }

   public void stop(BundleContext context)
   {
      if (service != null)
      {
         service.stop();
         service = null;
      }
   }
}
